@@ -12,9 +12,10 @@ class BaseCmd(cmd.Cmd):
     repeat_last_nonempty_command = False
 
     def emptyline(self):
-        """Do not repeat last command if input empty unlese repeat_last_command."""
+        """Do not repeat the last command if input empty unless forced to."""
         if self.repeat_last_nonempty_command:
             return super(BaseCmd, self).emptyline()
+        return None
 
     def do_exit(self, arg):
         """Exit the interpreter. You can also use the Ctrl-D shortcut."""
@@ -58,15 +59,20 @@ class BaseCmd(cmd.Cmd):
     def pre_loop_iter(self):
         """Excute before every loop iteration."""
 
-    def loop_once(self):
-        self.pre_loop_iter()
+    def _get_input(self):
         if self.cmdqueue:
-            line = self.cmdqueue.pop(0)
+            return self.cmdqueue.pop(0)
         else:
             try:
-                line = self.get_input()
+                return self.get_input()
             except KeyboardInterrupt:
-                return
+                return None
+
+    def loop_once(self):
+        self.pre_loop_iter()
+        line = self._get_input()
+        if line is None:
+            return None
 
         if line == 'exit':
             line = 'EOF'
