@@ -7,7 +7,7 @@ from robot import run_cli
 TEST_SUITE = b'''*** Settings ***
 Library  DebugLibrary
 
-** test case **
+** test cases **
 RFDEBUG REPL
     debug
 '''
@@ -30,7 +30,7 @@ def shell():
             args = default_no_logs.split() + [test_file.name]
 
         try:
-            rc = run_cli(args)
+            sys.exit(run_cli(args))
         finally:
             test_file.close()
             # pybot will raise PermissionError on Windows NT or later
@@ -39,8 +39,6 @@ def shell():
             if os.path.exists(test_file.name):
                 os.unlink(test_file.name)
 
-    sys.exit(rc)
-
 
 if __name__ == "__main__":
     # Usage: python -m DebugLibrary.shell
